pub fn read_text_file_capped(path: &Path) -> Result<String, CappedReadError>Expand description
Read a UTF-8 text file only when its size is within SOURCE_FILE_READ_MAX_BYTES.
pub fn read_text_file_capped(path: &Path) -> Result<String, CappedReadError>Read a UTF-8 text file only when its size is within SOURCE_FILE_READ_MAX_BYTES.