CargoAllowDiagnostic

Struct CargoAllowDiagnostic 

pub struct CargoAllowDiagnostic {
    pub code: String,
    pub category: String,
    pub severity: CargoAllowDiagnosticSeverity,
    pub path: Option<String>,
    pub span: Option<CargoAllowErrorLocation>,
    pub entry_id: Option<String>,
    pub field: Option<String>,
    pub message: String,
    pub help: Option<String>,
    pub causes: Vec<String>,
}
Structured validation or execution detail.

The fields are intentionally owned and optional so diagnostics can be produced by policy, federation, import, and command layers without making those layers depend on a parser-specific representation.

Fields

code: Stringcategory: Stringseverity: CargoAllowDiagnosticSeveritypath: Option<String>span: Option<CargoAllowErrorLocation>entry_id: Option<String>field: Option<String>message: Stringhelp: Option<String>causes: Vec<String>

Implementations

Source

impl CargoAllowDiagnostic

pub fn error( code: impl Into<String>, category: impl Into<String>, entry_id: Option<&str>, field: Option<&str>, message: impl Into<String>, ) -> Self